#!/bin/bash
#
#    .kmdr Installer/Updater/Uninstaller
#    Copyright (C) 2007 mx01
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.

APPNAME="Tiny Password Generator"
app=tinypwgen

kdeprefix=`kde-config --prefix`
bindir=$kdeprefix/bin
applnkdir=$kdeprefix/share/applnk/Utilities
menudir=$kdeprefix/share/menu/

function install_required_package()
{
  if [ -z "$(which $1)" ]; then
    echo "The $2 package is required, but not yet installed."
    if ! [ -z "$(cat /etc/lsb-release|grep -i Ubuntu)" ]; then
      read -p "I can it install for you. Proceed (y/n)?" -n 1 choice
      echo
      ! [ "$choice" = "y" ] && exit 1
      apt-get install $2
      if [ $? -ne 0 ]; then
        read -p "An error has occurred. Proceed anyway (y/n)?" -n 1 choice
        echo
        ! [ "$choice" = "y" ] && exit 1
      fi
    else
      echo "Please use the software installer of your distribution, then restart this installer."
      exit 1
    fi
    echo
  fi
}

echo
echo "$APPNAME installer"
echo
if [ `id -u` -ne 0 ]; then
  echo "You must start this installer as root."
  echo "Try: sudo ./install.sh"
  exit 1
fi

install_required_package pwgen pwgen
install_required_package kmdr-executor kommander

[ -f $bindir/$app.kmdr ] && is_installed=1
action=u

if [ $is_installed ]; then
  echo "$APPNAME is already installed."
  read -p "What do you want to do? [u]pdate [r]emove [a]bort ->" -n 1 action
  echo
fi

if [ "$action" = "u" ]; then
  [ $is_installed ] && echo -n "Updating $APPNAME ..." || echo -n "Installing $APPNAME ..."
  cp $app.kmdr $bindir/
  cp $app $menudir/
  cp $app.desktop $applnkdir/
  chmod 755 $bindir/$app.kmdr
  chmod 644 $applnkdir/$app.desktop $menudir/$app
  echo " done."
else
  if [ "$action" = "r" ]; then
    echo -n "Removing $APPNAME ..."
    rm -f $bindir/$app.kmdr $applnkdir/$app.desktop $menudir/$app
   echo " done."
  else
    echo "Aborted. No changes have been made to your system."
  fi
fi
echo
